@@ -7,6 +7,7 @@
 #include "Compiler/Scope.h"
 #include "Token.h"
 #include "Rule.h"
+#include "Production.h"
 
 namespace storm {
 	namespace syntax {
@@ -115,6 +116,10 @@ namespace storm {
 			this->color = c;
 		}
 
+		Rule *RuleDecl::create(Scope scope) {
+			return new (this) Rule(this, scope);
+		}
+
 
 		/**
 		 * Tokens.
@@ -444,6 +449,13 @@ namespace storm {
 			indentType = type;
 		}
 
+		ProductionType *ProductionDecl::create(Package *into, Delimiters *delimiters, Scope scope) {
+			Str *name = this->name;
+			if (!name)
+				name = into->anonName();
+			return new (this) ProductionType(name, this, delimiters, scope);
+		}
+
 
 		/**
 		 * Custom declaration.
